#!/usr/bin/env python3

import pytest
import os
import pandas as pd

test_output_path = os.path.dirname(os.path.abspath(__file__)) + \
                '/../output/filterReads/'


@pytest.mark.singleend_human
def test_align_reads_singleend_human():
    assert os.path.exists(os.path.join(test_output_path, 'ENCLB969KTX/ENCLB969KTX.dedup.bam'))
    assert os.path.exists(os.path.join(test_output_path, 'ENCLB969KTX/ENCLB969KTX.dedup.bam.bai'))
    assert os.path.exists(os.path.join(test_output_path, 'ENCLB969KTX/ENCLB969KTX.dedup.qc'))

@pytest.mark.singleend_human
def test_align_reads_singleend_human():
    filtered_reads_report = test_output_path + 'ENCLB969KTX/ENCLB969KTX.dedup.flagstat.qc'
    samtools_report = open(filtered_reads_report).readlines()
    assert '28118054 + 0 in total' in samtools_report[0]
    assert '28118054 + 0 mapped (100.00%:N/A)' in samtools_report[4]

@pytest.mark.singleend
def test_library_complexity_singleend():
    library_complexity = test_output_path + 'ENCLB969KTX/ENCLB969KTX.pbc.qc'
    df_library_complexity = pd.read_csv(library_complexity, sep='\t')
    assert  df_library_complexity["NRF"].iloc[0] == 0.608847
    assert  df_library_complexity["PBC1"].iloc[0] == 0.641176
    assert  df_library_complexity["PBC2"].iloc[0] == 2.887092


@pytest.mark.pairedend_mouse
def test_align_reads_pairedend_mouse():
    assert os.path.exists(os.path.join(test_output_path, 'ENCLB122XDP/ENCLB122XDP.dedup.bam'))
    assert os.path.exists(os.path.join(test_output_path, 'ENCLB122XDP/ENCLB122XDP.dedup.bam.bai'))
    assert os.path.exists(os.path.join(test_output_path, 'ENCLB122XDP/ENCLB122XDP.dedup.qc'))

@pytest.mark.pairedend_mouse
def test_align_reads_pairedend_mouse():
    filtered_reads_report = test_output_path + 'ENCLB122XDP/ENCLB122XDP.dedup.flagstat.qc'
    samtools_report = open(filtered_reads_report).readlines()
    assert '34342124 + 0 in total' in samtools_report[0]
    assert '34342124 + 0 mapped (100.00%:N/A)' in samtools_report[4]

@pytest.mark.pairedend_mouse
def test_align_reads_pairedend_mouse():
    library_complexity = test_output_path + 'ENCLB122XDP/ENCLB122XDP.pbc.qc'
    df_library_complexity = pd.read_csv(library_complexity, sep='\t')
    assert  df_library_complexity["NRF"].iloc[0] == 0.912926
    assert  round(df_library_complexity["PBC1"].iloc[0],6) == 0.913898
    assert  round(df_library_complexity["PBC2"].iloc[0],6) == 11.654689
