#!/usr/bin/env python3

import pytest
import pandas as pd
from io import StringIO
import os
import utils
import overlap_peaks

test_output_path = os.path.dirname(os.path.abspath(__file__)) + \
                '/../output/consensusPeaks/'

DESIGN_STRING = """sample_id\tbam_reads\tbam_index\texperiment_id\treplicate
A_1\tA_1.bam\tA_1.bai\tA\t1
A_2\tA_2.bam\tA_2.bai\tA\t2
B_1\tB_1.bam\tB_1.bai\tB\t1
B_2\tB_2.bam\tB_2.bai\tB\t2
"""


@pytest.fixture
def design_diff():
    design_file = StringIO(DESIGN_STRING)
    design_df = pd.read_csv(design_file, sep="\t")
    return design_df


@pytest.mark.unit
def test_check_update_design(design_diff):
    atac = True
    new_design = overlap_peaks.update_design(design_diff, atac)
    assert new_design.shape[0] == 4
    assert new_design.loc[0, 'peak_caller'] == "bed"


@pytest.mark.integration
def test_overlap_peaks_singleend():
    assert os.path.exists(os.path.join(test_output_path, 'ENCSR265ZXX.rejected.narrowPeak'))
    peak_file = test_output_path + 'ENCSR265ZXX.replicated.narrowPeak'
    #assert utils.count_lines(peak_file) == 150302


@pytest.mark.integration
def test_call_peaks_macs_pairedend():
    # Do the same thing for paired end data
    pass
